@@ -437,8 +437,8 @@ ClpDynamicExampleMatrix::partialPricing(ClpSimplex * model, double startFraction
     ClpPackedMatrix::partialPricing(model,startFraction,endFraction,bestSequence,numberWanted);
   } else {
     // and do some proportion of full set
-    int startG2 = (int) (startFraction*numberSets_);
-    int endG2 = (int) (endFraction*numberSets_+0.1);
+    int startG2 = static_cast<int> (startFraction*numberSets_);
+    int endG2 = static_cast<int> (endFraction*numberSets_+0.1);
     endG2 = CoinMin(endG2,numberSets_);
     //printf("gub price - set start %d end %d\n",
     //   startG2,endG2);
