@@ -6,7 +6,7 @@
 
 #include <stdio.h>
 
-#include <assert.h>
+#include <cassert>
 #include <iostream>
 
 #include "CoinHelperFunctions.hpp"
@@ -14,6 +14,7 @@
 #include "CoinPackedMatrix.hpp"
 #include "ClpPackedMatrix.hpp"
 #include "ClpSimplex.hpp"
+#include "ClpSimplexOther.hpp"
 #ifndef SLIM_CLP
 #include "ClpQuadraticObjective.hpp"
 #endif
@@ -271,7 +272,11 @@ ClpPresolve::postsolve(bool updateStatus)
   memset(originalModel_->primalRowSolution(),0,nrows_*sizeof(double));
   originalModel_->times(1.0,originalModel_->primalColumnSolution(),
 			originalModel_->primalRowSolution());
-  originalModel_->checkSolutionInternal();
+  originalModel_->checkSolutionInternal();  
+  if (originalModel_->sumDualInfeasibilities()>1.0e-1) {
+    // See if we can fix easily
+    static_cast<ClpSimplexOther *> (originalModel_)->cleanupAfterPostsolve();
+  }
   // Messages
   presolvedModel_->messageHandler()->message(COIN_PRESOLVE_POSTSOLVE,
 					    messages)
@@ -440,7 +445,10 @@ const CoinPresolveAction *ClpPresolve::presolve(CoinPresolveMatrix *prob)
     const bool slackd = doSingleton();
     const bool doubleton = doDoubleton();
     const bool tripleton = doTripleton();
+    //#define NO_FORCING
+#ifndef NO_FORCING
     const bool forcing = doForcing();
+#endif
     const bool ifree = doImpliedFree();
     const bool zerocost = doTighten();
     const bool dupcol = doDupcol();
@@ -476,7 +484,16 @@ const CoinPresolveAction *ClpPresolve::presolve(CoinPresolveMatrix *prob)
     check_sol(prob,1.0e0);
 #endif
     if (dupcol) {
-      //paction_ = dupcol_action::presolve(prob, paction_);
+      // maybe allow integer columns to be checked
+      if ((presolveActions_&512)!=0)
+	prob->setPresolveOptions(prob->presolveOptions()|1);
+      paction_ = dupcol_action::presolve(prob, paction_);
+    }
+    if (duprow) {
+      paction_ = duprow_action::presolve(prob, paction_);
+    }
+    if (doGubrow()) {
+      paction_ = gubrow_action::presolve(prob, paction_);
     }
 
     if ((presolveActions_&16384)!=0)
@@ -493,9 +510,23 @@ const CoinPresolveAction *ClpPresolve::presolve(CoinPresolveMatrix *prob)
 #endif
       const CoinPresolveAction * const paction0 = paction_;
       // look for substitutions with no fill
+      //#define IMPLIED 3
+#ifdef IMPLIED
+      int fill_level=3;
+#define IMPLIED2 99
+#if IMPLIED!=3
+#if IMPLIED>2&&IMPLIED<11
+      fill_level=IMPLIED;
+      printf("** fill_level == %d !\n",fill_level);
+#endif
+#if IMPLIED>11&&IMPLIED<21
+      fill_level=-(IMPLIED-10);
+      printf("** fill_level == %d !\n",fill_level);
+#endif
+#endif
+#else
       int fill_level=2;
-      //fill_level=10;
-      //printf("** fill_level == 10 !\n");
+#endif
       int whichPass=0;
       while (1) {
 	whichPass++;
@@ -533,15 +564,16 @@ const CoinPresolveAction *ClpPresolve::presolve(CoinPresolveMatrix *prob)
 	  if (prob->status_)
 	    break;
 	}
-
+#ifndef NO_FORCING
 	if (forcing) {
 	  paction_ = forcing_constraint_action::presolve(prob, paction_);
 	  if (prob->status_)
 	    break;
 	}
+#endif
 
 	if (ifree&&(whichPass%5)==1) {
-	paction_ = implied_free_action::presolve(prob, paction_,fill_level);
+	  paction_ = implied_free_action::presolve(prob, paction_,fill_level);
 	if (prob->status_)
 	  break;
 	}
@@ -641,8 +673,15 @@ const CoinPresolveAction *ClpPresolve::presolve(CoinPresolveMatrix *prob)
 	    break;
 	  const CoinPresolveAction * const paction2 = paction_;
 	  if (ifree) {
-	    //int fill_level=0; // switches off substitution
-	    paction_ = implied_free_action::presolve(prob, paction_,fill_level);
+#ifdef IMPLIED
+#if IMPLIED2 ==0
+	    int fill_level=0; // switches off substitution
+#elif IMPLIED2!=99
+	    int fill_level=IMPLIED2;
+#endif
+#endif
+	    if ((itry&1)==0)
+	      paction_ = implied_free_action::presolve(prob, paction_,fill_level);
 	    if (prob->status_)
 	      break;
 	  }
@@ -651,7 +690,13 @@ const CoinPresolveAction *ClpPresolve::presolve(CoinPresolveMatrix *prob)
 	}
       } else if (ifree) {
 	// just free
+#ifdef IMPLIED
+#if IMPLIED2 ==0
 	int fill_level=0; // switches off substitution
+#elif IMPLIED2!=99
+	int fill_level=IMPLIED2;
+#endif
+#endif
 	paction_ = implied_free_action::presolve(prob, paction_,fill_level);
 	if (prob->status_)
 	  break;
@@ -798,7 +843,7 @@ void ClpPresolve::postsolve(CoinPostsolveMatrix &prob)
 #endif
   
   while (paction) {
-#if	PRESOLVE_DEBUG
+#if PRESOLVE_DEBUG
     printf("POSTSOLVING %s\n", paction->name());
 #endif
 
@@ -809,8 +854,15 @@ void ClpPresolve::postsolve(CoinPostsolveMatrix &prob)
     int nr=0;
     int i;
     for (i=0;i<prob.nrows_;i++) {
-      if ((prob.rowstat_[i]&7)==1)
+      if ((prob.rowstat_[i]&7)==1) {
         nr++;
+      } else if ((prob.rowstat_[i]&7)==2) {
+	// at ub
+	assert (prob.acts_[i]>prob.rup_[i]-1.0e-6);
+      } else if ((prob.rowstat_[i]&7)==3) {
+	// at lb
+	assert (prob.acts_[i]<prob.rlo_[i]+1.0e-6);
+      }
     }
     int nc=0;
     for (i=0;i<prob.ncols_;i++) {
@@ -958,7 +1010,7 @@ CoinPrePostsolveMatrix::CoinPrePostsolveMatrix(const ClpSimplex * si,
     messages_()
 
 {
-  bulk0_ = (CoinBigIndex) (bulkRatio_*nelems_in);
+  bulk0_ = static_cast<CoinBigIndex> (bulkRatio_*nelems_in);
   hrow_  = new int   [bulk0_];
   colels_ = new double[bulk0_];
   si->getDblParam(ClpObjOffset,originalOffset_);
@@ -1054,7 +1106,6 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
   nextRowsToDo_(new int[nrows_in]),
   numberNextRowsToDo_(0),
   presolveOptions_(0)
-
 {
   const int bufsize = bulk0_;
 
@@ -1071,27 +1122,29 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
   // Do the copy here to try to avoid running out of memory.
 
   const CoinBigIndex * start = m->getVectorStarts();
-  const int * length = m->getVectorLengths();
   const int * row = m->getIndices();
   const double * element = m->getElements();
   int icol,nel=0;
   mcstrt_[0]=0;
+  ClpDisjointCopyN(m->getVectorLengths(),ncols_,  hincol_);
   for (icol=0;icol<ncols_;icol++) {
-    int j;
-    for (j=start[icol];j<start[icol]+length[icol];j++) {
+    CoinBigIndex j;
+    for (j=start[icol];j<start[icol]+hincol_[icol];j++) {
       hrow_[nel]=row[j];
-      colels_[nel++]=element[j];
+      if (fabs(element[j])>ZTOLDP)
+	colels_[nel++]=element[j];
     }
     mcstrt_[icol+1]=nel;
+    hincol_[icol]=nel-mcstrt_[icol];
   }
-  assert(mcstrt_[ncols_] == nelems_);
-  ClpDisjointCopyN(m->getVectorLengths(),ncols_,  hincol_);
 
   // same thing for row rep
   CoinPackedMatrix * mRow = new CoinPackedMatrix();
-  mRow->reverseOrderedCopyOf(*m);
-  mRow->removeGaps();
   mRow->setExtraGap(0.0);
+  mRow->setExtraMajor(0.0);
+  mRow->reverseOrderedCopyOf(*m);
+  //mRow->removeGaps();
+  //mRow->setExtraGap(0.0);
 
   // Now get rid of matrix
   si->createEmptyMatrix();
@@ -1116,12 +1169,30 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
   delete [] strt;
   hinrow_ = new int[nrows_in+1];
   ClpDisjointCopyN(len, nrows_,  hinrow_);
+  if (nelems_>nel) {
+    nelems_ = nel;
+    // Clean any small elements
+    int irow;
+    nel=0;
+    CoinBigIndex start=0;
+    for (irow=0;irow<nrows_;irow++) {
+      CoinBigIndex j;
+      for (j=start;j<start+hinrow_[irow];j++) {
+	hcol_[nel]=hcol_[j];
+	if (fabs(rowels_[j])>ZTOLDP)
+	  rowels_[nel++]=rowels_[j];
+      }
+      start=mrstrt_[irow+1];
+      mrstrt_[irow+1]=nel;
+      hinrow_[irow]=nel-mrstrt_[irow];
+    }
+  }
 
   delete mRow;
   if (si->integerInformation()) {
-    CoinMemcpyN((unsigned char *) si->integerInformation(),ncols_,integerType_);
+    CoinMemcpyN(reinterpret_cast<unsigned char *> (si->integerInformation()),ncols_,integerType_);
   } else {
-    ClpFillN<unsigned char>(integerType_, ncols_, (unsigned char) 0);
+    ClpFillN<unsigned char>(integerType_, ncols_, static_cast<unsigned char> (0));
   }
 
 #ifndef SLIM_CLP
@@ -1206,6 +1277,8 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
   // this must come after the calls to presolve_prefix
   mcstrt_[ncols_] = bufsize-1;
   mrstrt_[nrows_] = bufsize-1;
+  // Allocate useful arrays
+  initializeStuff();
 
 #if	PRESOLVE_CONSISTENCY
 //consistent(false);
@@ -1227,7 +1300,7 @@ void CoinPresolveMatrix::update_model(ClpSimplex * si,
       numberIntegers++;
   }
   if (numberIntegers) 
-    si->copyInIntegerInformation((const char *) integerType_);
+    si->copyInIntegerInformation(reinterpret_cast<const char *> (integerType_));
   else
     si->copyInIntegerInformation(NULL);
 
@@ -1506,6 +1579,8 @@ ClpPresolve::gutsOfPresolvedModel(ClpSimplex * originalModel,
 
     // Do presolve
     paction_ = presolve(&prob);
+    // Get rid of useful arrays
+    prob.deleteStuff();
 
     result =0; 
 
