@@ -18,10 +18,11 @@
 class ClpDualRowPivot;
 class ClpPrimalColumnPivot;
 class ClpFactorization;
+#include "ClpFactorization.hpp"
 class CoinIndexedVector;
 class ClpNonLinearCost;
 class ClpNodeStuff;
-class CoinModel;
+class CoinStructuredModel;
 class OsiClpSolverInterface;
 class CoinWarmStartBasis;
 class ClpDisasterHandler;
@@ -64,9 +65,9 @@ public:
   // For Dual
   enum FakeBound {
     noFake = 0x00,
-    bothFake = 0x01,
+    lowerFake = 0x01,
     upperFake = 0x02,
-    lowerFake = 0x03
+    bothFake = 0x03
   };
 
   /**@name Constructors and destructor and copy */
@@ -120,25 +121,6 @@ public:
       2 as 1 but give a bit extra if bigger needed
   */
   void setPersistenceFlag(int value);
-  /**
-     If you are re-using the same matrix again and again then the setup time
-     to do scaling may be significant.  Also you may not want to initialize all values
-     or return all values (especially if infeasible).  While an auxiliary model exists
-     it will be faster.  If options -1 then model is switched off.  Otherwise switched on
-     with following options.
-     1 - rhs is constant
-     2 - bounds are constant
-     4 - objective is constant
-     8 - solution in by basis and no djs etc in
-     16 - no duals out (but reduced costs)
-     32 - no output if infeasible
-  */
-  void auxiliaryModel(int options);
-  /// Switch off e.g. if people using presolve
-  void deleteAuxiliaryModel();
-  /// See if we have auxiliary model
-  inline bool usingAuxiliaryModel() const
-  { return auxiliaryModel_!=NULL;}
   /// Save a copy of model with certain state - normally without cuts
   void makeBaseModel();
   /// Switch off base model
@@ -290,6 +272,16 @@ public:
   /** Solves non-linear using reduced gradient.  Phase = 0 get feasible,
       =1 use solution */
   int reducedGradient(int phase=0);
+  /// Solve using structure of model and maybe in parallel
+  int solve(CoinStructuredModel * model);
+  /** This loads a model from a CoinStructuredModel object - returns number of errors.
+      If originalOrder then keep to order stored in blocks,
+      otherwise first column/rows correspond to first block - etc.
+      If keepSolution true and size is same as current then
+      keeps current status and solution
+  */
+  int loadProblem (  CoinStructuredModel & modelObject,
+		     bool originalOrder=true,bool keepSolution=false);
   /**
      When scaling is on it is possible that the scaled problem
      is feasible but the unscaled is not.  Clp returns a secondary
@@ -537,6 +529,8 @@ public:
   /// Set algorithm
   inline void setAlgorithm(int value)
   {algorithm_=value; } 
+  /// Return true if the objective limit test can be relied upon
+  bool isObjectiveLimitTestValid() const ;
   /// Sum of dual infeasibilities
   inline double sumDualInfeasibilities() const 
           { return sumDualInfeasibilities_;} 
@@ -694,6 +688,15 @@ protected:
   void checkDualSolution();
   /** This sets sum and number of infeasibilities (Dual and Primal) */
   void checkBothSolutions();
+  /**  If input negative scales objective so maximum <= -value
+       and returns scale factor used.  If positive unscales and also
+       redoes dual stuff
+  */
+  double scaleObjective(double value);
+  /// Solve using Dantzig-Wolfe decomposition and maybe in parallel
+  int solveDW(CoinStructuredModel * model);
+  /// Solve using Benders decomposition and maybe in parallel
+  int solveBenders(CoinStructuredModel * model);
 public:
   /** For advanced use.  When doing iterative solves things can get
       nasty so on values pass if incoming solution has largest
@@ -717,9 +720,12 @@ public:
   inline void setAlphaAccuracy(double value)
           { alphaAccuracy_ = value;} 
 public:
-  /// Disaster handler
+  /// Set disaster handler
   inline void setDisasterHandler(ClpDisasterHandler * handler)
   { disasterArea_= handler;}
+  /// Get disaster handler
+  inline ClpDisasterHandler * disasterHandler() const
+  { return disasterArea_;}
   /// Large bound value (for complementarity etc)
   inline double largeValue() const 
           { return largeValue_;} 
@@ -736,6 +742,12 @@ public:
   /// Largest error on basic duals
   inline void setLargestDualError(double value)
           { largestDualError_=value;} 
+  /// Get zero tolerance
+  inline double zeroTolerance() const 
+  { return zeroTolerance_;/*factorization_->zeroTolerance();*/} 
+  /// Set zero tolerance
+  inline void setZeroTolerance( double value)
+  { zeroTolerance_ = value;}
   /// Basic variables pivoting on which rows
   inline int * pivotVariable() const
           { return pivotVariable_;}
@@ -840,8 +852,8 @@ public:
   inline void setStatus(int sequence, Status status)
   {
     unsigned char & st_byte = status_[sequence];
-    st_byte &= ~7;
-    st_byte |= status;
+    st_byte = static_cast<unsigned char>(st_byte & ~7);
+    st_byte = static_cast<unsigned char>(st_byte | status);
   }
   /// Start or reset using maximumRows_ and Columns_ - true if change
   bool startPermanentArrays();
@@ -916,6 +928,10 @@ public:
   /// Theta (pivot change)
   inline double theta() const
   { return theta_;}
+  /** Best possible improvement using djs (primal) or 
+      obj change by flipping bounds to make dual feasible (dual) */
+  inline double bestPossibleImprovement() const
+  { return bestPossibleImprovement_;}
   /// Return pointer to details of costs
   inline ClpNonLinearCost * nonLinearCost() const
   { return nonLinearCost_;}
@@ -924,6 +940,8 @@ public:
       2 bit - if presolved problem infeasible return
       4 bit - keep arrays like upper_ around
       8 bit - if factorization kept can still declare optimal at once
+      16 bit - if checking replaceColumn accuracy before updating
+      32 bit - say optimal if primal feasible!
   */
   inline int moreSpecialOptions() const
   { return moreSpecialOptions_;}
@@ -940,49 +958,49 @@ public:
   inline void setFakeBound(int sequence, FakeBound fakeBound)
   {
     unsigned char & st_byte = status_[sequence];
-    st_byte &= ~24;
-    st_byte |= fakeBound<<3;
+    st_byte = static_cast<unsigned char>(st_byte & ~24);
+    st_byte = static_cast<unsigned char>(st_byte | (fakeBound<<3));
   }
   inline FakeBound getFakeBound(int sequence) const
   {return static_cast<FakeBound> ((status_[sequence]>>3)&3);}
   inline void setRowStatus(int sequence, Status status)
   {
     unsigned char & st_byte = status_[sequence+numberColumns_];
-    st_byte &= ~7;
-    st_byte |= status;
+    st_byte = static_cast<unsigned char>(st_byte & ~7);
+    st_byte = static_cast<unsigned char>(st_byte | status);
   }
   inline Status getRowStatus(int sequence) const
   {return static_cast<Status> (status_[sequence+numberColumns_]&7);}
   inline void setColumnStatus(int sequence, Status status)
   {
     unsigned char & st_byte = status_[sequence];
-    st_byte &= ~7;
-    st_byte |= status;
+    st_byte = static_cast<unsigned char>(st_byte & ~7);
+    st_byte = static_cast<unsigned char>(st_byte | status);
   }
   inline Status getColumnStatus(int sequence) const
   {return static_cast<Status> (status_[sequence]&7);}
   inline void setPivoted( int sequence)
-  { status_[sequence] |= 32;}
+  { status_[sequence] = static_cast<unsigned char>(status_[sequence] | 32);}
   inline void clearPivoted( int sequence)
-  { status_[sequence] &= ~32; }
+  { status_[sequence] = static_cast<unsigned char>(status_[sequence] & ~32);}
   inline bool pivoted(int sequence) const
   {return (((status_[sequence]>>5)&1)!=0);}
   /// To flag a variable (not inline to allow for column generation)
   void setFlagged( int sequence);
   inline void clearFlagged( int sequence)
   {
-    status_[sequence] &= ~64;
+    status_[sequence] = static_cast<unsigned char>(status_[sequence] & ~64);
   }
   inline bool flagged(int sequence) const
   {return ((status_[sequence]&64)!=0);}
   /// To say row active in primal pivot row choice
   inline void setActive( int iRow)
   {
-    status_[iRow] |= 128;
+    status_[iRow] = static_cast<unsigned char>(status_[iRow] | 128);
   }
   inline void clearActive( int iRow)
   {
-    status_[iRow] &= ~128;
+    status_[iRow] = static_cast<unsigned char>(status_[iRow] & ~128);
   }
   inline bool active(int iRow) const
   {return ((status_[iRow]&128)!=0);}
@@ -998,7 +1016,7 @@ public:
   {return lastBadIteration_;}
   /// Progress flag - at present 0 bit says artificials out
   inline int progressFlag() const
-  {return progressFlag_;}
+  {return (progressFlag_&3);}
   /// Force re-factorization early 
   inline void forceFactorization(int value)
   { forceFactorization_ = value;}
@@ -1145,10 +1163,11 @@ protected:
    single array is the owner of memory 
   */
   //@{
-  /// Worst column primal infeasibility
-  double columnPrimalInfeasibility_;
-  /// Worst row primal infeasibility
-  double rowPrimalInfeasibility_;
+  /** Best possible improvement using djs (primal) or 
+      obj change by flipping bounds to make dual feasible (dual) */
+  double bestPossibleImprovement_;
+  /// Zero tolerance
+  double zeroTolerance_;
   /// Sequence of worst (-1 if feasible)
   int columnPrimalSequence_;
   /// Sequence of worst (-1 if feasible)
@@ -1257,8 +1276,6 @@ protected:
   double * rowActivityWork_;
   /// Column activities - working copy
   double * columnActivityWork_;
-  /// Auxiliary model
-  ClpSimplex * auxiliaryModel_;
   /// Number of dual infeasibilities
   int numberDualInfeasibilities_;
   /// Number of dual infeasibilities (without free)
@@ -1337,6 +1354,10 @@ protected:
   double allowedInfeasibility_;
   /// Automatic scaling of objective and rhs and bounds
   int automaticScale_;
+  /// Maximum perturbation array size (take out when code rewritten)
+  int maximumPerturbationSize_;
+  /// Perturbation array (maximumPerturbationSize_)
+  double * perturbationArray_;
   /// A copy of model with certain state - normally without cuts
   ClpSimplex * baseModel_;
   /// For dealing with all issues of cycling etc
